#!/bin/sh

RELEASEDATE=20130404

svn co -r \{$((${RELEASEDATE} + 1))\} \
	https://sauerbraten.svn.sourceforge.net/svnroot/sauerbraten/src \
	sauerbraten-0.0.${RELEASEDATE}+dfsg

find sauerbraten-0.0.${RELEASEDATE}+dfsg -type d -name '.svn' \
	-exec rm -rf "{}" \;
rm -rf sauerbraten-0.0.${RELEASEDATE}+dfsg/vcpp
rm -rf sauerbraten-0.0.${RELEASEDATE}+dfsg/xcode
rm -rf sauerbraten-0.0.${RELEASEDATE}+dfsg/lib
rm -rf sauerbraten-0.0.${RELEASEDATE}+dfsg/lib64
rm -rf sauerbraten-0.0.${RELEASEDATE}+dfsg/enet
tar -czf sauerbraten_0.0.${RELEASEDATE}+dfsg.orig.tar.gz \
	sauerbraten-0.0.${RELEASEDATE}+dfsg

rm -rf sauerbraten-0.0.${RELEASEDATE}+dfsg
